# SDK Configuration Instructions for Bugsink

[Bugsink](https://www.bugsink.com/) offers real-time [error
tracking](https://www.bugsink.com/error-tracking/) for your applications with
full control through self-hosting. 

### SDK Conf

This is the repository and associated pypi package that contains the
per-platform instructions to integrate your application with Bugsink.

The per-platform instructions show up in 2 places:

* in your local Bugsink installation when you click on the "configure SDK" button
* as part of the docs on the Bugsink website

This repository is intentionally separate from the main Bugsink repository
to allow for a separate (Open Source) License and associated friendly
approach to contributions.
